==> vtigercrm-5.0.3.tgz: vtigercrm/modules/Vendors/language/en_us.lang.php <==
<?php
/*********************************************************************************
** The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
*
 ********************************************************************************/


$mod_strings = array(

'LBL_VENDOR_INFORMATION'=>'Vendor Information:',
'LBL_CUSTOM_INFORMATION'=>'Custom Information',
'LBL_VENDOR_ADDRESS_INFORMATION'=>'Address Information:',
'LBL_DESCRIPTION_INFORMATION'=>'Description Name:',


'Vendor Name'=>'Vendor Name',
'Name'=>'Name',
'Company Name'=>'Company Name',
'Phone'=>'Phone',
'Email'=>'Email',
'Website'=>'Website',
'GL Account'=>'GL Account',
'Category'=>'Category',
'Street'=>'Street',
'City'=>'City',
'State'=>'State',
'Postal Code'=>'Postal Code',
'Country'=>'Country',
'Description'=>'Description',
'Po Box'=>'PO Box',
'Vendor'=>'Vendor',

//Added for existing Picklist entries

'300-Sales-Software'=>'300-Sales-Software',
'301-Sales-Hardware'=>'301-Sales-Hardware',
'302-Rental-Income'=>'302-Rental-Income',
'303-Interest-Income'=>'303-Interest-Income',
'304-Sales-Software-Support'=>'304-Sales-Software-Support',
'305-Sales Other'=>'305-Sales Other',
'306-Internet Sales'=>'306-Internet Sales',
'307-Service-Hardware Labor'=>'307-Service-Hardware Labor',
'308-Sales-Books'=>'308-Sales-Books',


);
?>

==> vtigercrm-5.0.4p0.tgz: vtigercrm/modules/Vendors/language/en_us.lang.php <==
<?php
/*********************************************************************************
** The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
*
 ********************************************************************************/


$mod_strings = array(

'LBL_VENDOR_INFORMATION'=>'Vendor Information:',
'LBL_CUSTOM_INFORMATION'=>'Custom Information',
'LBL_VENDOR_ADDRESS_INFORMATION'=>'Address Information:',
'LBL_DESCRIPTION_INFORMATION'=>'Description Name:',


'Vendor Name'=>'Vendor Name',
'Name'=>'Name',
'Company Name'=>'Company Name',
'Phone'=>'Phone',
'Email'=>'Email',
'Website'=>'Website',
'GL Account'=>'GL Account',
'Category'=>'Category',
'Street'=>'Street',
'City'=>'City',
'State'=>'State',
'Postal Code'=>'Postal Code',
'Country'=>'Country',
'Description'=>'Description',
'Po Box'=>'PO Box',
'Vendor'=>'Vendor',

//Added for existing Picklist entries

'300-Sales-Software'=>'300-Sales-Software',
'301-Sales-Hardware'=>'301-Sales-Hardware',
'302-Rental-Income'=>'302-Rental-Income',
'303-Interest-Income'=>'303-Interest-Income',
'304-Sales-Software-Support'=>'304-Sales-Software-Support',
'305-Sales Other'=>'305-Sales Other',
'306-Internet Sales'=>'306-Internet Sales',
'307-Service-Hardware Labor'=>'307-Service-Hardware Labor',
'308-Sales-Books'=>'308-Sales-Books',

// Added/Updated for vtiger CRM 5.0.4
'Created Time'=>'Created Time',
'Modified Time'=>'Modified Time',

);
?>
